Extraction
=================
In order to save space, you might want to extract the information from the
HTMLs directly, without saving the HTMLs themselves. The library does allow
you to do that. In this section, we will show you how you can define your
own extractors.


.. toctree::
    :maxdepth: 2
    :caption: Contents:

    creating_extractor
    config_file
    utils
